#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concurrent-output
version:              1.10.21
visibility:           public
id:                   concurrent-output-1.10.21-FmC8XG1tvMYCTKrouOrnH0
key:                  concurrent-output-1.10.21-FmC8XG1tvMYCTKrouOrnH0
license:              BSD-2-Clause
copyright:            2015-2021 Joey Hess, 2009 Joachim Breitner
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess, Joachim Breitner
stability:            Stable
synopsis:             Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.

    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.

    <<https://joeyh.name/code/concurrent-output/demo2.gif>>

category:             User Interfaces, Concurrency
abi:                  621ac32e45abf79313a710cb984e9d7f
exposed:              True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent

hidden-modules:       Utility.Monad Utility.Exception
import-dirs:          /usr/lib/ghc-9.6.6/site-local/concurrent-output-1.10.21
library-dirs:         /usr/lib/ghc-9.6.6/site-local/concurrent-output-1.10.21
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/concurrent-output-1.10.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-output
hs-libraries:         HSconcurrent-output-1.10.21-FmC8XG1tvMYCTKrouOrnH0
depends:
    ansi-terminal-1.1-6Y22U2Ur51rJg2I79RgMg8
    async-2.2.6-IoWj97vUYPEHBO7shudLcv base-4.18.2.1 directory-1.3.8.5
    exceptions-0.10.7 process-1.6.19.0 stm-2.5.1.0
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

